{
  inputs,
  pkgs,
  config,
  # these come in via home-manager.extraSpecialArgs and are specific to each node
  nodeFlake,
  packages',
  ...
}: let
  pkgsUnstable = pkgs.callPackage nodeFlake.inputs.nixpkgs-unstable.outPath {};
  pkgsMaster = pkgs.callPackage nodeFlake.inputs.nixpkgs-master.outPath {};
in {
  imports = [
    ../profiles/common.nix
    ../profiles/dotfiles.nix
    # FIXME: fix homeshick when no WAN connection is available
    # ../programs/homeshick.nix

    ../programs/redshift.nix
    ../programs/espanso.nix
    ../programs/gnome-desktop.nix
    ../programs/gpg-agent.nix

    ../programs/radicale.nix

    ../programs/firefox.nix
    ../programs/chromium.nix

    ../programs/libreoffice.nix
    ../programs/neovim.nix
    ../programs/pass.nix
    ../programs/vscode

    ../programs/holochain-launcher.nix
  ];

  home.sessionVariables.HM_CONFIG = "graphical-fullblown";
  home.sessionVariables.GOPATH = "$HOME/src/go";
  home.sessionVariables.PATH = pkgs.lib.concatStringsSep ":" ["$HOME/.local/bin" "$PATH"];

  home.packages =
    []
    ++ (with pkgs; [
      # Authentication
      cacert
      fprintd
      openssl
      mkpasswd

      # Nix package related tools
      patchelf
      nix-index
      nix-prefetch-scripts
      # nix-prefetch-github

      # Version Control Systems
      gitFull
      pijul
      # gitless
      gitRepo
      git-lfs

      # Process/System Administration
      htop
      # gnome.gnome-tweaks
      xorg.xhost
      dmidecode
      evtest

      # Archive Managers
      sshfs-fuse
      xarchive
      p7zip
      zip
      unzip
      gzip
      lzop

      # Password Management
      gnupg
      # yubikey-manager
      yubikey-manager-qt
      yubikey-personalization
      yubikey-personalization-gui
      gnome.gnome-keyring
      # gnome.seahorse

      # Language Support
      hunspellDicts.en-us
      hunspellDicts.de-de

      # Messaging/Communication
      signal-desktop
      pidgin
      hexchat
      aspellDicts.en
      aspellDicts.de
      skypeforlinux
      pkgsUnstable.jitsi-meet-electron
      thunderbird
      evolution # gnome4.glib_networking
      kotatogram-desktop
      zoom-us
      thunderbird
      gnome.cheese
      pkgsMaster.discord

      # Virtualization
      # virtmanager

      # Remote Control Tools
      remmina
      freerdp
      teamviewer
      rustdesk

      # Audio/Video Players
      ffmpeg
      vlc
      audacity
      spotify
      # youtube-dl-light
      libwebcam

      # Network Tools
      openvpn
      tcpdump
      iftop
      iperf
      bind
      socat
      # 2019-03-05: broken on 19.03 linssid
      iptraf-ng
      ipmitool

      iptables
      nftables
      wireshark
      wireguard-tools

      # Code Editors
      xclip
      xsel

      # Image/Graphic/Design Tools
      gnome.eog
      gimp
      imagemagick
      exiv2
      graphviz
      inkscape
      qrencode
      zbar
      feh

      # TODO: remove or move these: Modelling Tools
      # plantuml
      # umlet
      # staruml
      # eclipses.eclipse-modeling
      # dia
      # astah-community

      # Misc Development Tools
      qrcode
      jq
      cdrtools

      # Document Processing and Management
      mendeley
      (pkgsUnstable.logseq.override (_: {electron = pkgs.electron_20;}))

      # File Synchronzation
      dropbox
      rsync

      # Filesystem Tools
      ntfs3g
      ddrescue
      ncdu
      unetbootin
      hdparm
      testdisk
      # binwalk
      gptfdisk
      gparted
      smartmontools

      ## Android
      androidenv.androidPkgs_9_0.platform-tools

      ## Python
      packages'.myPython

      # Misc Desktop Tools
      ltunify
      # dex
      xorg.xbacklight
      coreutils
      lsof
      xdotool
      xdg_utils
      xdg-user-dirs
      dconf
      picocom
      glib.dev # contains gdbus tool
      alacritty
      wally-cli
      man-pages

      # Screen recording
      # gtk-recordmydesktop # can't select the window
      # qt-recordmydesktop
      # vokoscreen
      # shutter
      # kazam # doesn't start
      # xvidcap # doesn't keep the recording rectangle
      # obs-studio
      # shotcut
      # openshot-qt
      # introduces python: screenkey

      pkgsUnstable.ledger-live-desktop
    ]);

  systemd.user.startServices = true;
  services.syncthing.enable = true;
}
